@@ -569,6 +569,7 @@ static void init_tab_general(GtkWidget *dialog,
 
 void dt_gui_preferences_show()
 {
+  dt_stop_backthumbs_crawler(FALSE);
   GtkWindow *win = GTK_WINDOW(dt_ui_main_window(darktable.gui->ui));
   _preferences_dialog =
     gtk_dialog_new_with_buttons(_("darktable preferences"), win,
@@ -581,11 +582,13 @@ void dt_gui_preferences_show()
 #endif
   gtk_widget_set_name(_preferences_dialog, "preferences-notebook");
 
-  //grab the content area of the dialog
-  GtkWidget *box = gtk_dialog_get_content_area(GTK_DIALOG(_preferences_dialog));
-  gtk_widget_set_name(box, "preferences-box");
+  GtkWidget *content = gtk_dialog_get_content_area(GTK_DIALOG(_preferences_dialog));
+  gtk_widget_set_name(content, "preferences-box");
+  // changing orientation of content area to horizontal causes wide (empty) action-box
+  // so insert an hbox instead
+  GtkWidget *box = dt_gui_hbox();
   gtk_container_set_border_width(GTK_CONTAINER(box), 0);
-  gtk_orientable_set_orientation(GTK_ORIENTABLE(box), GTK_ORIENTATION_HORIZONTAL);
+  dt_gui_box_add(content, box);
 
   //create stack and sidebar and pack into the box
   GtkWidget *stack = gtk_stack_new();
@@ -631,6 +634,7 @@ void dt_gui_preferences_show()
   if(restart_required)
     dt_control_log(_("darktable needs to be restarted for settings to take effect"));
 
+  dt_start_backthumbs_crawler();
   DT_CONTROL_SIGNAL_RAISE(DT_SIGNAL_PREFERENCES_CHANGE);
 }
 
